@@ -1,7 +1,7 @@
 /*
  * Photos - access, organize and share your photos on GNOME
  * Copyright © 2013 Intel Corporation. All rights reserved.
- * Copyright © 2013 – 2019 Red Hat, Inc.
+ * Copyright © 2013 – 2021 Red Hat, Inc.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -59,18 +59,6 @@ G_DEFINE_TYPE_WITH_CODE (PhotosDlnaRenderer, photos_dlna_renderer, G_TYPE_OBJECT
                                                 photos_dlna_renderer_async_initable_iface_init));
 
 
-#define RETURN_ON_ERROR(task, error, msg) \
-  G_STMT_START { \
-    if (error != NULL) \
-      { \
-        g_warning ("%s: %s: %s", G_STRFUNC, msg, error->message); \
-        g_task_return_error (task, error); \
-        g_object_unref (task); \
-        return; \
-      } \
-  } G_STMT_END
-
-
 static void
 photos_dlna_renderer_dispose (GObject *object)
 {
@@ -260,17 +248,21 @@ photos_dlna_renderer_device_proxy_new_cb (GObject *source_object,
                                           GAsyncResult *res,
                                           gpointer user_data)
 {
-  GTask *init_task = G_TASK (user_data);
+  g_autoptr (GTask) init_task = G_TASK (user_data);
   PhotosDlnaRenderer *self;
   GError *error = NULL;
 
   self = PHOTOS_DLNA_RENDERER (g_task_get_source_object (init_task));
 
   self->device = dleyna_renderer_device_proxy_new_for_bus_finish (res, &error);
-  RETURN_ON_ERROR (init_task, error, "Unable to load the RendererDevice interface");
+  if (error != NULL)
+    {
+      g_warning ("%s: Unable to load the RendererDevice interface: %s", G_STRFUNC, error->message);
+      g_task_return_error (init_task, error);
+      return;
+    }
 
   g_task_return_boolean (init_task, TRUE);
-  g_object_unref (init_task);
 }
 
 
@@ -282,7 +274,7 @@ photos_dlna_renderer_init_async (GAsyncInitable *initable,
                                  gpointer user_data)
 {
   PhotosDlnaRenderer *self = PHOTOS_DLNA_RENDERER (initable);
-  GTask *init_task;
+  g_autoptr (GTask) init_task = NULL;
   GError *error = NULL;
 
   init_task = g_task_new (initable, cancellable, callback, user_data);
@@ -295,7 +287,12 @@ photos_dlna_renderer_init_async (GAsyncInitable *initable,
                                                                       self->object_path,
                                                                       NULL,
                                                                       &error);
-  RETURN_ON_ERROR (init_task, error, "Unable to load the PushHost interface");
+  if (error != NULL)
+    {
+      g_warning ("%s: Unable to load the PushHost interface: %s", G_STRFUNC, error->message);
+      g_task_return_error (init_task, error);
+      return;
+    }
 
   self->player = mpris_player_proxy_new_for_bus_sync (self->bus_type,
                                                       G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES
@@ -304,7 +301,12 @@ photos_dlna_renderer_init_async (GAsyncInitable *initable,
                                                       self->object_path,
                                                       NULL,
                                                       &error);
-  RETURN_ON_ERROR (init_task, error, "Unable to load the Player interface");
+  if (error != NULL)
+    {
+      g_warning ("%s: Unable to load the Player interface: %s", G_STRFUNC, error->message);
+      g_task_return_error (init_task, error);
+      return;
+    }
 
   dleyna_renderer_device_proxy_new_for_bus (self->bus_type,
                                             G_DBUS_PROXY_FLAGS_NONE,
@@ -312,7 +314,7 @@ photos_dlna_renderer_init_async (GAsyncInitable *initable,
                                             self->object_path,
                                             cancellable,
                                             photos_dlna_renderer_device_proxy_new_cb,
-                                            init_task);
+                                            g_object_ref (init_task));
 }
 
 
@@ -320,13 +322,12 @@ PhotosDlnaRenderer*
 photos_dlna_renderer_new_for_bus_finish (GAsyncResult *result,
                                          GError **error)
 {
-  GObject *object, *source_object;
+  GObject *object;
+  g_autoptr (GObject) source_object = NULL;
   GError *err = NULL;
 
   source_object = g_async_result_get_source_object (result);
   object = g_async_initable_new_finish (G_ASYNC_INITABLE (source_object), result, &err);
-  g_object_unref (source_object);
-
   if (err != NULL)
     {
       g_clear_object (&object);
@@ -357,16 +358,20 @@ photos_dlna_renderer_share_play_cb (GObject *source_object,
                                     GAsyncResult *res,
                                     gpointer user_data)
 {
-  GTask *task = G_TASK (user_data);
+  g_autoptr (GTask) task = G_TASK (user_data);
   PhotosBaseItem *item;
   GError *error = NULL;
 
   mpris_player_call_play_finish (MPRIS_PLAYER (source_object), res, &error);
-  RETURN_ON_ERROR (task, error, "Failed to call the Play method");
+  if (error != NULL)
+    {
+      g_warning ("%s: Failed to call the Play method: %s", G_STRFUNC, error->message);
+      g_task_return_error (task, error);
+      return;
+    }
 
   item = g_object_get_data (G_OBJECT (task), "item");
   g_task_return_pointer (task, g_object_ref (item), g_object_unref);
-  g_object_unref (task);
 }
 
 
@@ -375,20 +380,25 @@ photos_dlna_renderer_share_open_uri_cb (GObject *source_object,
                                         GAsyncResult *res,
                                         gpointer user_data)
 {
-  GTask *task = G_TASK (user_data);
+  g_autoptr (GTask) task = G_TASK (user_data);
   PhotosDlnaRenderer *self;
   GError *error = NULL;
 
   self = PHOTOS_DLNA_RENDERER (g_task_get_source_object (task));
 
   mpris_player_call_open_uri_finish (MPRIS_PLAYER (source_object), res, &error);
-  RETURN_ON_ERROR (task, error, "Failed to call the OpenUri method");
+  if (error != NULL)
+    {
+      g_warning ("%s: Failed to call the OpenUri method: %s", G_STRFUNC, error->message);
+      g_task_return_error (task, error);
+      return;
+    }
 
   /* 3) Mpris.Player.Play() */
   mpris_player_call_play (self->player,
                           g_task_get_cancellable (task),
                           photos_dlna_renderer_share_play_cb,
-                          task);
+                          g_object_ref (task));
 }
 
 
@@ -397,7 +407,7 @@ photos_dlna_renderer_share_host_file_cb (GObject *source_object,
                                          GAsyncResult *res,
                                          gpointer user_data)
 {
-  GTask *task = G_TASK (user_data);
+  g_autoptr (GTask) task = G_TASK (user_data);
   PhotosDlnaRenderer *self;
   PhotosBaseItem *item;
   gchar *hosted_url;
@@ -409,7 +419,12 @@ photos_dlna_renderer_share_host_file_cb (GObject *source_object,
                                                    &hosted_url,
                                                    res,
                                                    &error);
-  RETURN_ON_ERROR (task, error, "Failed to call the HostFile method");
+  if (error != NULL)
+    {
+      g_warning ("%s: Failed to call the HostFile method: %s", G_STRFUNC, error->message);
+      g_task_return_error (task, error);
+      return;
+    }
 
   item = g_object_get_data (G_OBJECT (task), "item");
   g_hash_table_replace (self->urls_to_item, hosted_url, g_object_ref (item));
@@ -420,7 +435,7 @@ photos_dlna_renderer_share_host_file_cb (GObject *source_object,
   mpris_player_call_open_uri (self->player, hosted_url,
                               g_task_get_cancellable (task),
                               photos_dlna_renderer_share_open_uri_cb,
-                              task);
+                              g_object_ref (task));
 }
 
 
@@ -431,15 +446,20 @@ photos_dlna_renderer_share_download_cb (GObject *source_object,
 {
   PhotosDlnaRenderer *self;
   GError *error;
-  GFile *file = NULL;
-  GTask *task = G_TASK (user_data);
-  gchar *filename;
+  g_autoptr (GFile) file = NULL;
+  g_autoptr (GTask) task = G_TASK (user_data);
+  g_autofree gchar *filename = NULL;
 
   self = PHOTOS_DLNA_RENDERER (g_task_get_source_object (task));
 
   error = NULL;
   file = photos_base_item_download_finish (PHOTOS_BASE_ITEM (source_object), res, &error);
-  RETURN_ON_ERROR (task, error, "Unable to extract the local filename for the shared item");
+  if (error != NULL)
+    {
+      g_warning ("%s: Unable to extract the local filename for the shared item: %s", G_STRFUNC, error->message);
+      g_task_return_error (task, error);
+      return;
+    }
 
   /* This will call a sequence of DBus methods to send the item to the DMR:
    * 1) DleynaRenderer.PushHost.HostFile (filename)
@@ -457,9 +477,7 @@ photos_dlna_renderer_share_download_cb (GObject *source_object,
                                             filename,
                                             g_task_get_cancellable (task),
                                             photos_dlna_renderer_share_host_file_cb,
-                                            task);
-  g_free (filename);
-  g_object_unref (file);
+                                            g_object_ref (task));
 }
 
 
@@ -470,12 +488,12 @@ photos_dlna_renderer_share (PhotosDlnaRenderer *self,
                             GAsyncReadyCallback callback,
                             gpointer user_data)
 {
-  GTask *task;
+  g_autoptr (GTask) task = NULL;
 
   task = g_task_new (self, cancellable, callback, user_data);
   g_object_set_data_full (G_OBJECT (task), "item", g_object_ref (item), g_object_unref);
 
-  photos_base_item_download_async (item, cancellable, photos_dlna_renderer_share_download_cb, task);
+  photos_base_item_download_async (item, cancellable, photos_dlna_renderer_share_download_cb, g_object_ref (task));
 }
 
 
@@ -507,31 +525,29 @@ photos_dlna_renderer_unshare_remove_file_cb (GObject *source_object,
                                              GAsyncResult *res,
                                              gpointer user_data)
 {
-  GTask *task = G_TASK (user_data);
+  g_autoptr (GTask) task = G_TASK (user_data);
   PhotosDlnaRenderer *self = PHOTOS_DLNA_RENDERER (g_task_get_source_object (task));
   PhotosBaseItem *item;
-  gboolean success = TRUE;
-  GError *error = NULL;
 
   item = g_object_get_data (G_OBJECT (task), "item");
   g_hash_table_foreach_remove (self->urls_to_item, photos_dlna_renderer_match_by_item_value, item);
   g_object_notify (G_OBJECT (self), "shared-count");
 
-  dleyna_renderer_push_host_call_remove_file_finish (DLEYNA_RENDERER_PUSH_HOST (source_object), res, &error);
-  if (error != NULL)
-    {
-      /* Assume that ignoring RemoveFile() errors is safe, since they
-       * are likely caused by the file being already removed or the
-       * DBus service having been restarted.
-       */
-      g_warning ("Failed to call the RemoveFile method: %s", error->message);
-      g_error_free (error);
-      success = FALSE;
-    }
+  {
+    g_autoptr (GError) error = NULL;
 
-  g_task_return_boolean (task, success);
+    dleyna_renderer_push_host_call_remove_file_finish (DLEYNA_RENDERER_PUSH_HOST (source_object), res, &error);
+    if (error != NULL)
+      {
+        /* Assume that ignoring RemoveFile() errors is safe, since they
+         * are likely caused by the file being already removed or the
+         * DBus service having been restarted.
+         */
+        g_warning ("Failed to call the RemoveFile method: %s", error->message);
+      }
+  }
 
-  g_object_unref (task);
+  g_task_return_boolean (task, TRUE);
 }
 
 
@@ -542,24 +558,27 @@ photos_dlna_renderer_unshare_download_cb (GObject *source_object,
 {
   PhotosDlnaRenderer *self;
   GError *error;
-  GFile *file = NULL;
-  GTask *task = G_TASK (user_data);
-  gchar *filename;
+  g_autoptr (GFile) file = NULL;
+  g_autoptr (GTask) task = G_TASK (user_data);
+  g_autofree gchar *filename = NULL;
 
   self = PHOTOS_DLNA_RENDERER (g_task_get_source_object (task));
 
   error = NULL;
   file = photos_base_item_download_finish (PHOTOS_BASE_ITEM (source_object), res, &error);
-  RETURN_ON_ERROR (task, error, "Unable to extract the local filename for the shared item");
+  if (error != NULL)
+    {
+      g_warning ("%s: Unable to extract the local filename for the shared item: %s", G_STRFUNC, error->message);
+      g_task_return_error (task, error);
+      return;
+    }
 
   filename = g_file_get_path (file);
   dleyna_renderer_push_host_call_remove_file (self->push_host,
                                               filename,
                                               g_task_get_cancellable (task),
                                               photos_dlna_renderer_unshare_remove_file_cb,
-                                              task);
-  g_free (filename);
-  g_object_unref (file);
+                                              g_object_ref (task));
 }
 
 
@@ -570,23 +589,26 @@ photos_dlna_renderer_unshare (PhotosDlnaRenderer *self,
                               GAsyncReadyCallback callback,
                               gpointer user_data)
 {
-  GTask *task;
+  g_autoptr (GTask) task = NULL;
 
   task = g_task_new (self, cancellable, callback, user_data);
   g_object_set_data_full (G_OBJECT (task), "item", g_object_ref (item), g_object_unref);
 
-  photos_base_item_download_async (item, cancellable, photos_dlna_renderer_unshare_download_cb, task);
+  photos_base_item_download_async (item,
+                                   cancellable,
+                                   photos_dlna_renderer_unshare_download_cb,
+                                   g_object_ref (task));
 }
 
 
-void
+gboolean
 photos_dlna_renderer_unshare_finish (PhotosDlnaRenderer *self,
                                      GAsyncResult *res,
                                      GError **error)
 {
-  g_return_if_fail (g_task_is_valid (res, self));
+  g_return_val_if_fail (g_task_is_valid (res, self), FALSE);
 
-  g_task_propagate_boolean (G_TASK (res), error);
+  return g_task_propagate_boolean (G_TASK (res), error);
 }
 
 
@@ -596,23 +618,23 @@ photos_dlna_renderer_unshare_all_unshare_cb (GObject *source_object,
                                              gpointer user_data)
 {
   PhotosDlnaRenderer *self = PHOTOS_DLNA_RENDERER (source_object);
-  GTask *task = G_TASK (user_data);
+  g_autoptr (GTask) task = G_TASK (user_data);
   guint remaining;
-  GError *error = NULL;
 
   /* decrement the remaining count */
   remaining = GPOINTER_TO_UINT (g_task_get_task_data (task));
   g_task_set_task_data (task, GUINT_TO_POINTER (--remaining), NULL);
 
-  photos_dlna_renderer_unshare_finish (self, res, &error);
+  {
+    g_autoptr (GError) error = NULL;
 
-  if (error != NULL)
-    g_warning ("Unable to unshare item: %s", error->message);
+    if (!photos_dlna_renderer_unshare_finish (self, res, &error))
+      g_warning ("Unable to unshare item: %s", error->message);
+  }
 
   if (remaining == 0)
     {
       g_task_return_boolean (task, TRUE);
-      g_object_unref (task);
       return;
     }
 }
@@ -623,8 +645,9 @@ photos_dlna_renderer_unshare_all (PhotosDlnaRenderer  *self,
                                   GAsyncReadyCallback callback,
                                   gpointer user_data)
 {
-  GTask *task;
-  GList *items, *item;
+  GList *item;
+  g_autoptr (GList) items = NULL;
+  g_autoptr (GTask) task = NULL;
   guint remaining;
 
   task = g_task_new (self, cancellable, callback, user_data);
@@ -636,20 +659,18 @@ photos_dlna_renderer_unshare_all (PhotosDlnaRenderer  *self,
 
   for (item = items; item != NULL; item = g_list_next (item))
     photos_dlna_renderer_unshare (self, PHOTOS_BASE_ITEM (item->data), cancellable,
-                                  photos_dlna_renderer_unshare_all_unshare_cb, task);
-
-  g_list_free (items);
+                                  photos_dlna_renderer_unshare_all_unshare_cb, g_object_ref (task));
 }
 
 
-void
+gboolean
 photos_dlna_renderer_unshare_all_finish (PhotosDlnaRenderer *self,
                                          GAsyncResult *res,
                                          GError **error)
 {
-  g_return_if_fail (g_task_is_valid (res, self));
+  g_return_val_if_fail (g_task_is_valid (res, self), FALSE);
 
-  g_task_propagate_boolean (G_TASK (res), error);
+  return g_task_propagate_boolean (G_TASK (res), error);
 }
 
 
@@ -658,16 +679,14 @@ photos_dlna_renderer_device_get_icon_cb (GObject *source_object,
                                          GAsyncResult *res,
                                          gpointer user_data)
 {
-  GTask *task = G_TASK (user_data);
-  GInputStream *icon_stream;
+  g_autoptr (GTask) task = G_TASK (user_data);
+  g_autoptr (GInputStream) icon_stream = NULL;
   GdkPixbuf *pixbuf;
   GtkIconSize size;
-  GVariant *icon_variant;
-  GBytes *icon_bytes;
-  const gchar *icon_data;
+  g_autoptr (GBytes) icon_bytes = NULL;
+  g_autoptr (GVariant) icon_variant = NULL;
   gint height = -1;
   gint width = -1;
-  gsize icon_data_size;
   GError *error = NULL;
 
   /* The icon data is forced to be a GVariant since the GDBus bindings
@@ -676,33 +695,36 @@ photos_dlna_renderer_device_get_icon_cb (GObject *source_object,
    */
   dleyna_renderer_device_call_get_icon_finish (DLEYNA_RENDERER_DEVICE (source_object),
                                                &icon_variant, NULL, res, &error);
-  RETURN_ON_ERROR (task, error, "Failed to call the GetIcon method");
+  if (error != NULL)
+    {
+      g_warning ("%s: Failed to call the GetIcon method: %s", G_STRFUNC, error->message);
+      g_task_return_error (task, error);
+      return;
+    }
 
   /* We know that the serialization of variant containing just a byte
    * array 'ay' is the byte array itself.
    */
   icon_bytes = g_variant_get_data_as_bytes (icon_variant);
-  g_variant_unref (icon_variant);
-
-  icon_data = g_bytes_get_data (icon_bytes, &icon_data_size);
-  g_bytes_unref (icon_bytes);
 
   size = (GtkIconSize) GPOINTER_TO_INT (g_task_get_task_data (task));
   gtk_icon_size_lookup (size, &width, &height);
 
-  icon_stream = g_memory_input_stream_new_from_data (icon_data, icon_data_size, NULL);
+  icon_stream = g_memory_input_stream_new_from_bytes (icon_bytes);
   pixbuf = gdk_pixbuf_new_from_stream_at_scale (icon_stream,
                                                 width,
                                                 height,
                                                 TRUE,
                                                 g_task_get_cancellable (task),
                                                 &error);
-  g_object_unref (icon_stream);
+  if (error != NULL)
+    {
+      g_warning ("%s: Failed to parse icon data: %s", G_STRFUNC, error->message);
+      g_task_return_error (task, error);
+      return;
+    }
 
-  RETURN_ON_ERROR (task, error, "Failed to parse icon data");
   g_task_return_pointer (task, pixbuf, g_object_unref);
-
-  g_object_unref (task);
 }
 
 
@@ -730,14 +752,14 @@ photos_dlna_renderer_get_icon (PhotosDlnaRenderer *self,
                                GAsyncReadyCallback callback,
                                gpointer user_data)
 {
-  GTask *task;
+  g_autoptr (GTask) task = NULL;
 
   task = g_task_new (self, cancellable, callback, user_data);
   g_task_set_task_data (task, GINT_TO_POINTER (size), NULL);
 
   dleyna_renderer_device_call_get_icon (self->device, requested_mimetype, resolution,
                                         cancellable, photos_dlna_renderer_device_get_icon_cb,
-                                        task);
+                                        g_object_ref (task));
 }
 
 
