@@ -1,7 +1,7 @@
 /*
  * Photos - access, organize and share your photos on GNOME
  * Copyright © 2013 Intel Corporation. All rights reserved.
- * Copyright © 2013 – 2019 Red Hat, Inc.
+ * Copyright © 2013 – 2021 Red Hat, Inc.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,6 +39,7 @@
 struct _PhotosDlnaRenderersDialog
 {
   GtkDialog parent_instance;
+  GCancellable *cancellable;
   PhotosBaseManager *item_mngr;
   PhotosDlnaRenderersManager *renderers_mngr;
   PhotosRemoteDisplayManager *remote_mngr;
@@ -82,6 +83,12 @@ photos_dlna_renderers_dialog_dispose (GObject *object)
 {
   PhotosDlnaRenderersDialog *self = PHOTOS_DLNA_RENDERERS_DIALOG (object);
 
+  if (self->cancellable != NULL)
+    {
+      g_cancellable_cancel (self->cancellable);
+      g_clear_object (&self->cancellable);
+    }
+
   g_clear_object (&self->item_mngr);
   g_clear_object (&self->renderers_mngr);
   g_clear_object (&self->remote_mngr);
@@ -128,24 +135,29 @@ photos_dlna_renderers_dialog_set_icon_cb (GObject      *source_object,
                                           GAsyncResult *res,
                                           gpointer      user_data)
 {
-  GdkPixbuf *pixbuf;
-  GtkImage *image = GTK_IMAGE (user_data);
+  g_autoptr (GdkPixbuf) pixbuf = NULL;
+  GtkImage *image;
   PhotosDlnaRenderer *renderer = PHOTOS_DLNA_RENDERER (source_object);
-  GError *error = NULL;
 
-  pixbuf = photos_dlna_renderer_get_icon_finish (renderer, res, &error);
-  if (error != NULL)
-    {
-      g_warning ("Unable to load renderer icon: %s", error->message);
-      g_error_free (error);
-      goto out;
-    }
+  {
+    g_autoptr (GError) error = NULL;
+
+    pixbuf = photos_dlna_renderer_get_icon_finish (renderer, res, &error);
+    if (error != NULL)
+      {
+        if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+          g_warning ("Unable to load renderer icon: %s", error->message);
+
+        goto out;
+      }
+  }
+
+  image = GTK_IMAGE (user_data);
 
   gtk_image_set_from_pixbuf (image, pixbuf);
 
-out:
-  /* release the ref we took before the async call */
-  g_object_unref (image);
+ out:
+  return;
 }
 
 
@@ -175,12 +187,11 @@ photos_dlna_renderers_dialog_add_renderer (PhotosDlnaRenderersDialog *self, Phot
   icon = g_themed_icon_new_with_default_fallbacks ("video-display-symbolic");
   image = gtk_image_new_from_gicon (icon, GTK_ICON_SIZE_DIALOG);
 
-  g_object_ref (image); /* keep a ref for the following async call and release it in the callback */
   photos_dlna_renderer_get_icon (renderer,
                                  "",
                                  "",
                                  GTK_ICON_SIZE_DIALOG,
-                                 NULL,
+                                 self->cancellable,
                                  photos_dlna_renderers_dialog_set_icon_cb,
                                  image);
 
@@ -196,7 +207,8 @@ static void
 photos_dlna_renderers_dialog_init (PhotosDlnaRenderersDialog *self)
 {
   GApplication *app;
-  GList *renderers;
+  GList *l;
+  g_autolist (PhotosDlnaRenderer) renderers = NULL;
   PhotosSearchContextState *state;
 
   app = g_application_get_default ();
@@ -212,14 +224,10 @@ photos_dlna_renderers_dialog_init (PhotosDlnaRenderersDialog *self)
   gtk_list_box_set_header_func (self->listbox, photos_utils_list_box_header_func, NULL, NULL);
 
   renderers = photos_dlna_renderers_manager_dup_renderers (self->renderers_mngr);
-
-  while (renderers != NULL)
+  for (l = renderers; l != NULL; l = l->next)
     {
-      PhotosDlnaRenderer *renderer = PHOTOS_DLNA_RENDERER (renderers->data);
-
+      PhotosDlnaRenderer *renderer = PHOTOS_DLNA_RENDERER (l->data);
       photos_dlna_renderers_dialog_add_renderer (self, renderer);
-      renderers = g_list_delete_link (renderers, renderers);
-      g_object_unref (renderer);
     }
 
   g_signal_connect (self, "response", G_CALLBACK (gtk_widget_destroy), NULL);
