@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2019 Red Hat, Inc.
+ * Copyright © 2012 – 2021 Red Hat, Inc.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -69,14 +69,6 @@ photos_filterable_get_id (PhotosFilterable *self)
 }
 
 
-gchar *
-photos_filterable_get_where (PhotosFilterable *self)
-{
-  g_return_val_if_fail (PHOTOS_IS_FILTERABLE (self), NULL);
-  return PHOTOS_FILTERABLE_GET_IFACE (self)->get_where (self);
-}
-
-
 gboolean
 photos_filterable_is_search_criterion (PhotosFilterable *self)
 {
