@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2019 Red Hat, Inc.
+ * Copyright © 2012 – 2021 Red Hat, Inc.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 #include <glib/gi18n.h>
 #include <tracker-sparql.h>
 
+#include "photos-application.h"
 #include "photos-debug.h"
 #include "photos-device-item.h"
 #include "photos-enums.h"
@@ -41,8 +42,6 @@
 #include "photos-query.h"
 #include "photos-search-context.h"
 #include "photos-single-item-job.h"
-#include "photos-tracker-change-event.h"
-#include "photos-tracker-change-monitor.h"
 #include "photos-tracker-queue.h"
 #include "photos-utils.h"
 
@@ -60,9 +59,9 @@ struct _PhotosItemManager
   PhotosBaseItem *active_collection;
   PhotosBaseManager **item_mngr_chldrn;
   PhotosLoadState load_state;
-  PhotosTrackerChangeMonitor *monitor;
   PhotosTrackerQueue *queue;
   PhotosWindowMode mode;
+  TrackerNotifier *notifier;
   gboolean fullscreen;
   gboolean *constrain_additions;
   guint wait_for_changes_id;
@@ -311,7 +310,7 @@ photos_item_manager_add_cursor_for_mode (PhotosItemManager *self,
   g_return_if_fail (base_item_type == G_TYPE_NONE
                     || (base_item_type != PHOTOS_TYPE_BASE_ITEM
                         && g_type_is_a (base_item_type, PHOTOS_TYPE_BASE_ITEM)));
-  g_return_if_fail (TRACKER_SPARQL_IS_CURSOR (cursor));
+  g_return_if_fail (TRACKER_IS_SPARQL_CURSOR (cursor));
   g_return_if_fail (mode != PHOTOS_WINDOW_MODE_NONE);
   g_return_if_fail (mode != PHOTOS_WINDOW_MODE_EDIT);
   g_return_if_fail (mode != PHOTOS_WINDOW_MODE_PREVIEW);
@@ -529,21 +528,24 @@ photos_item_manager_item_created (PhotosItemManager *self, const gchar *urn)
 
 
 static void
-photos_item_manager_changes_pending_foreach (gpointer key, gpointer value, gpointer user_data)
+photos_item_manager_notifier_events_foreach (gpointer data, gpointer user_data)
 {
   PhotosItemManager *self = PHOTOS_ITEM_MANAGER (user_data);
-  PhotosTrackerChangeEvent *change_event = (PhotosTrackerChangeEvent *) value;
-  PhotosTrackerChangeEventType change_type;
-  const gchar *change_urn;
+  TrackerNotifierEvent *event = (TrackerNotifierEvent *) data;
+  TrackerNotifierEventType event_type;
+  const gchar *event_urn;
 
-  change_type = photos_tracker_change_event_get_type (change_event);
-  change_urn = photos_tracker_change_event_get_urn (change_event);
+  event_type = tracker_notifier_event_get_event_type (event);
+  event_urn = tracker_notifier_event_get_urn (event);
+  photos_debug (PHOTOS_DEBUG_TRACKER, "Received TrackerNotifierEvent (%d): URN %s", event_type, event_urn);
 
-  if (change_type == PHOTOS_TRACKER_CHANGE_EVENT_CHANGED)
+  g_return_if_fail (event_urn != NULL && event_urn[0] != '\0');
+
+  if (event_type == TRACKER_NOTIFIER_EVENT_UPDATE)
     {
       GObject *object;
 
-      object = photos_base_manager_get_object_by_id (PHOTOS_BASE_MANAGER (self), change_urn);
+      object = photos_base_manager_get_object_by_id (PHOTOS_BASE_MANAGER (self), event_urn);
       if (object != NULL)
         {
           photos_base_item_refresh (PHOTOS_BASE_ITEM (object));
@@ -553,33 +555,37 @@ photos_item_manager_changes_pending_foreach (gpointer key, gpointer value, gpoin
               const gchar *uri;
 
               uri = photos_base_item_get_uri (PHOTOS_BASE_ITEM (object));
-              photos_item_manager_check_wait_for_changes (self, change_urn, uri);
+              photos_item_manager_check_wait_for_changes (self, event_urn, uri);
             }
         }
     }
-  else if (change_type == PHOTOS_TRACKER_CHANGE_EVENT_CREATED)
+  else if (event_type == TRACKER_NOTIFIER_EVENT_CREATE)
     {
-      photos_item_manager_item_created (self, change_urn);
+      photos_item_manager_item_created (self, event_urn);
     }
-  else if (change_type == PHOTOS_TRACKER_CHANGE_EVENT_DELETED)
+  else if (event_type == TRACKER_NOTIFIER_EVENT_DELETE)
     {
       GObject *object;
 
-      object = photos_base_manager_get_object_by_id (PHOTOS_BASE_MANAGER (self), change_urn);
+      object = photos_base_manager_get_object_by_id (PHOTOS_BASE_MANAGER (self), event_urn);
       if (object != NULL)
         {
           photos_base_item_destroy (PHOTOS_BASE_ITEM (object));
-          g_hash_table_remove (self->hidden_items, change_urn);
-          photos_base_manager_remove_object_by_id (PHOTOS_BASE_MANAGER (self), change_urn);
+          g_hash_table_remove (self->hidden_items, event_urn);
+          photos_base_manager_remove_object_by_id (PHOTOS_BASE_MANAGER (self), event_urn);
         }
     }
 }
 
 
 static void
-photos_item_manager_changes_pending (PhotosItemManager *self, GHashTable *changes)
+photos_item_manager_notifier_events (PhotosItemManager *self,
+                                     const gchar *service,
+                                     const gchar *graph,
+                                     GPtrArray *events)
 {
-  g_hash_table_foreach (changes, photos_item_manager_changes_pending_foreach, self);
+  if (g_strcmp0 (graph, PHOTOS_PICTURES_GRAPH) == 0)
+    g_ptr_array_foreach (events, photos_item_manager_notifier_events_foreach, self);
 }
 
 
@@ -704,20 +710,35 @@ static gboolean
 photos_item_manager_wait_for_changes_timeout (gpointer user_data)
 {
   PhotosItemManager *self = PHOTOS_ITEM_MANAGER (user_data);
+  GApplication *app;
   GHashTableIter iter;
   GList *tasks;
+  const gchar *miner_files_name;
   const gchar *uri;
 
   if (G_UNLIKELY (self->queue == NULL))
     goto out;
 
+  app = g_application_get_default ();
+  miner_files_name = photos_application_get_miner_files_name (PHOTOS_APPLICATION (app));
+
   g_hash_table_iter_init (&iter, self->wait_for_changes_table);
   while (g_hash_table_iter_next (&iter, (gpointer *) &uri, (gpointer *) &tasks))
     {
       g_autoptr (PhotosQuery) query = NULL;
       g_autofree gchar *sparql = NULL;
 
-      sparql = g_strdup_printf ("SELECT ?urn nie:url (?urn) WHERE { ?urn nie:url '%s' }", uri);
+      sparql = g_strdup_printf ("SELECT ?urn ?file WHERE {"
+                                "  SERVICE <dbus:%s> {"
+                                "    GRAPH tracker:Pictures {"
+                                "      SELECT ?urn nie:isStoredAs (?urn) AS ?file WHERE {"
+                                "        ?urn nie:isStoredAs '%s' "
+                                "    }"
+                                "  }"
+                                "}",
+                                miner_files_name,
+                                uri);
+
       query = photos_query_new (NULL, sparql);
       photos_tracker_queue_select (self->queue,
                                    query,
@@ -1038,8 +1059,8 @@ photos_item_manager_dispose (GObject *object)
   g_clear_object (&self->active_object);
   g_clear_object (&self->loader_cancellable);
   g_clear_object (&self->active_collection);
-  g_clear_object (&self->monitor);
   g_clear_object (&self->queue);
+  g_clear_object (&self->notifier);
 
   G_OBJECT_CLASS (photos_item_manager_parent_class)->dispose (object);
 }
@@ -1093,14 +1114,6 @@ photos_item_manager_init (PhotosItemManager *self)
 
   self->mode = PHOTOS_WINDOW_MODE_NONE;
 
-  self->monitor = photos_tracker_change_monitor_dup_singleton (NULL, NULL);
-  if (G_LIKELY (self->monitor != NULL))
-    g_signal_connect_object (self->monitor,
-                             "changes-pending",
-                             G_CALLBACK (photos_item_manager_changes_pending),
-                             self,
-                             G_CONNECT_SWAPPED);
-
   {
     g_autoptr (GError) error = NULL;
 
@@ -1241,7 +1254,7 @@ photos_item_manager_add_item (PhotosItemManager *self,
   g_return_if_fail (base_item_type == G_TYPE_NONE
                     || (base_item_type != PHOTOS_TYPE_BASE_ITEM
                         && g_type_is_a (base_item_type, PHOTOS_TYPE_BASE_ITEM)));
-  g_return_if_fail (TRACKER_SPARQL_IS_CURSOR (cursor));
+  g_return_if_fail (TRACKER_IS_SPARQL_CURSOR (cursor));
 
   id = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_URN, NULL);
   g_return_if_fail (id != NULL && id[0] != '\0');
@@ -1370,7 +1383,7 @@ photos_item_manager_create_item (PhotosItemManager *self,
   g_return_val_if_fail (base_item_type == G_TYPE_NONE
                         || (base_item_type != PHOTOS_TYPE_BASE_ITEM
                             && g_type_is_a (base_item_type, PHOTOS_TYPE_BASE_ITEM)), NULL);
-  g_return_val_if_fail (TRACKER_SPARQL_IS_CURSOR (cursor), NULL);
+  g_return_val_if_fail (TRACKER_IS_SPARQL_CURSOR (cursor), NULL);
 
   id = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_URN, NULL);
   item = PHOTOS_BASE_ITEM (photos_base_manager_get_object_by_id (PHOTOS_BASE_MANAGER (self), id));
@@ -1522,6 +1535,26 @@ photos_item_manager_set_constraints_for_mode (PhotosItemManager *self, gboolean
 }
 
 
+void
+photos_item_manager_set_notifier (PhotosItemManager *self, TrackerNotifier *notifier)
+{
+  g_return_if_fail (PHOTOS_IS_ITEM_MANAGER (self));
+  g_return_if_fail (notifier == NULL || TRACKER_IS_NOTIFIER (notifier));
+
+  if (self->notifier != NULL)
+    {
+      g_signal_handlers_disconnect_by_func (self->notifier, photos_item_manager_notifier_events, self);
+      g_clear_object (&self->notifier);
+    }
+
+  if (notifier != NULL)
+    {
+      self->notifier = g_object_ref (notifier);
+      g_signal_connect_swapped (self->notifier, "events", G_CALLBACK (photos_item_manager_notifier_events), self);
+    }
+}
+
+
 void
 photos_item_manager_unhide_item (PhotosItemManager *self, PhotosBaseItem *item)
 {
