@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2020 Red Hat, Inc.
+ * Copyright © 2012 – 2021 Red Hat, Inc.
  * Copyright © 2009 Yorba Foundation
  *
  * This program is free software: you can redistribute it and/or modify
@@ -402,7 +402,7 @@ photos_utils_create_thumbnail (GFile *file,
 GVariant *
 photos_utils_create_zoom_target_value (gdouble delta, PhotosZoomEvent event)
 {
-  GEnumClass *zoom_event_class = NULL; /* TODO: use g_autoptr */
+  g_autoptr (GEnumClass) zoom_event_class = NULL;
   GEnumValue *event_value;
   GVariant *delta_value;
   GVariant *event_nick_value;
@@ -427,7 +427,6 @@ photos_utils_create_zoom_target_value (gdouble delta, PhotosZoomEvent event)
 
   ret_val = g_variant_builder_end (&builder);
 
-  g_type_class_unref (zoom_event_class);
   g_return_val_if_fail (g_variant_is_floating (ret_val), ret_val);
   return ret_val;
 }
@@ -544,7 +543,7 @@ photos_utils_get_zoom_delta (GVariant *dictionary)
 PhotosZoomEvent
 photos_utils_get_zoom_event (GVariant *dictionary)
 {
-  GEnumClass *zoom_event_class = NULL;
+  g_autoptr (GEnumClass) zoom_event_class = NULL;
   GEnumValue *event_value;
   PhotosZoomEvent ret_val = PHOTOS_ZOOM_EVENT_NONE;
   const gchar *event_str;
@@ -566,7 +565,6 @@ photos_utils_get_zoom_event (GVariant *dictionary)
   ret_val = (PhotosZoomEvent) event_value->value;
 
  out:
-  g_clear_pointer (&zoom_event_class, g_type_class_unref);
   g_return_val_if_fail (ret_val != PHOTOS_ZOOM_EVENT_NONE, PHOTOS_ZOOM_EVENT_NONE);
   return ret_val;
 }
@@ -1132,6 +1130,16 @@ photos_utils_get_version (void)
 }
 
 
+gboolean
+photos_utils_is_flatpak (void)
+{
+  gboolean ret_val;
+
+  ret_val = g_file_test ("/.flatpak-info", G_FILE_TEST_EXISTS);
+  return ret_val;
+}
+
+
 void
 photos_utils_launch_online_accounts (const gchar *account_id)
 {
@@ -1323,7 +1331,13 @@ photos_utils_set_edited_name (const gchar *urn, const gchar *title)
   g_autoptr (PhotosTrackerQueue) queue = NULL;
   g_autofree gchar *sparql = NULL;
 
-  sparql = g_strdup_printf ("INSERT OR REPLACE { <%s> nie:title \"%s\" }", urn, title);
+  sparql = g_strdup_printf ("WITH tracker:Pictures "
+                            "DELETE { <%s> nie:title ?title } "
+                            "INSERT { "
+                            "  <%s> a nmm:Photo ; nie:title \"%s\" . "
+                            "}"
+                            "WHERE { <%s> nie:title ?title }", urn, urn, title, urn);
+
   query = photos_query_new (NULL, sparql);
 
   {
@@ -1351,9 +1365,23 @@ photos_utils_set_favorite (const gchar *urn, gboolean is_favorite)
   g_autoptr (PhotosTrackerQueue) queue = NULL;
   g_autofree gchar *sparql = NULL;
 
-  sparql = g_strdup_printf ("%s { <%s> nao:hasTag nao:predefined-tag-favorite }",
-                            (is_favorite) ? "INSERT OR REPLACE" : "DELETE",
-                            urn);
+  if (is_favorite)
+    {
+      sparql = g_strdup_printf ("INSERT DATA { "
+                                "  GRAPH tracker:Pictures {"
+                                "    <%s> a nmm:Photo ; nao:hasTag nao:predefined-tag-favorite ."
+                                "  } "
+                                "}", urn);
+    }
+  else
+    {
+      sparql = g_strdup_printf ("DELETE DATA {"
+                                "  GRAPH tracker:Pictures {"
+                                "    <%s> nao:hasTag nao:predefined-tag-favorite "
+                                "  } "
+                                "}", urn);
+    }
+
   query = photos_query_new (NULL, sparql);
 
   {
