@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2020 Red Hat, Inc.
+ * Copyright © 2012 – 2021 Red Hat, Inc.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -45,9 +45,9 @@ G_BEGIN_DECLS
 #define PHOTOS_TOOL_EXTENSION_POINT_NAME "photos-tool"
 #define PHOTOS_TRACKER_CONTROLLER_EXTENSION_POINT_NAME "photos-tracker-controller"
 
-#define PHOTOS_COLLECTION_SCREENSHOT \
-  "http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#image-category-screenshot"
+#define PHOTOS_COLLECTION_SCREENSHOT "http://tracker.api.gnome.org/ontology/v3/nfo#image-category-screenshot"
 #define PHOTOS_EXPORT_SUBPATH "Exports"
+#define PHOTOS_PICTURES_GRAPH "http://tracker.api.gnome.org/ontology/v3/tracker#Pictures"
 
 typedef enum
 {
@@ -154,6 +154,8 @@ GList           *photos_utils_get_urns_from_items         (GList *items);
 
 const gchar     *photos_utils_get_version                 (void);
 
+gboolean         photos_utils_is_flatpak                  (void);
+
 void             photos_utils_launch_online_accounts      (const gchar *account_id);
 
 void             photos_utils_list_box_header_func        (GtkListBoxRow *row,
